Concepts
========
Here we cover several core conceptual topics related to modeling with
the Vivarium framework.

.. toctree::
   :maxdepth: 2

   configuration
   lifecycle
   entry_points
   crn
   values
   data
